@@ -51,30 +51,36 @@ def set_local_vars(self, config):
         print(e)
 
 
-def parse_record(record):
-    timestamp = {"timestamp": datetime.utcnow().isoformat()}
-    good = False
+def parse_record(record, custom_filter):
+    timestamp = {'timestamp': datetime.utcnow().isoformat()}
     try:
-        if "server" in record.msg and record.levelno == INFO:
-            record.msg["protocol"] = record.msg["server"].replace("_server", "")
-            del record.msg["server"]
+        if custom_filter is not None:
+            if 'remove_errors' in custom_filter['honeypots']['options']:
+                if 'error' in record.msg:
+                    return None
+            if 'remove_init' in custom_filter['honeypots']['options']:
+                if record.msg.get('action', None) == 'process':
+                    return None
+            if isinstance(record.msg, Mapping):
+                try:
+                    if 'honeypots' in custom_filter:
+                        for key in record.msg.copy():
+                            if key in custom_filter['honeypots']['change']:
+                                record.msg[custom_filter['honeypots']['change'][key]] = record.msg.pop(key)
+                        for key in record.msg.copy():
+                            if key not in custom_filter['honeypots']['keep']:
+                                del record.msg[key]
+                except Exception as e:
+                    pass
+        if isinstance(record.msg, Mapping):
             record.msg = serialize_object({**timestamp, **record.msg})
-            good = True
-        if not good:
+        else:
             record.msg = serialize_object(record.msg)
     except Exception as e:
         record.msg = {'name': record.name, 'error': repr(e)}
     return record
 
 
-class json_file_formatter(Formatter):
-    def __init__(self):
-        super().__init__()
-
-    def format(self, record):
-        return super().format(parse_record(record))
-
-
 def get_running_servers():
     temp_list = []
     try:
@@ -101,14 +107,16 @@ def setup_logger(name, temp_name, config, drop=False):
     syslog_address = ''
     syslog_facility = ''
     config_data = None
+    custom_filter = None
     if config and config != '':
         try:
             with open(config) as f:
                 config_data = load(f)
-                logs = config_data['logs']
-                logs_location = config_data['logs_location']
-                syslog_address = config_data['syslog_address']
-                syslog_facility = config_data['syslog_facility']
+                logs = config_data.get('logs', logs)
+                logs_location = config_data.get('logs_location', logs_location)
+                syslog_address = config_data.get('syslog_address', syslog_address)
+                syslog_facility = config_data.get('syslog_facility', syslog_facility)
+                custom_filter = config_data.get('custom_filter', custom_filter)
         except BaseException:
             pass
     if logs_location == '' or logs_location is None:
@@ -119,31 +127,26 @@ def setup_logger(name, temp_name, config, drop=False):
     ret_logs_obj = getLogger(temp_name)
     ret_logs_obj.setLevel(DEBUG)
     if 'db' in logs:
-        ret_logs_obj.addHandler(CustomHandler(temp_name, logs, config_data, drop))
+        ret_logs_obj.addHandler(CustomHandler(temp_name, logs, custom_filter, config_data, drop))
     elif 'terminal' in logs:
-        ret_logs_obj.addHandler(CustomHandler(temp_name, logs))
+        ret_logs_obj.addHandler(CustomHandler(temp_name, logs, custom_filter))
     if 'file' in logs:
         max_bytes = 10000
         backup_count = 10
         try:
             if config_data is not None:
-                if "honeypots" in config_data:
+                if 'honeypots' in config_data:
                     temp_server_name = name[1:].lower().replace('server', '')
-                    if temp_server_name in config_data["honeypots"]:
-                        if "log_file_name" in config_data["honeypots"][temp_server_name]:
-                            temp_name = config_data["honeypots"][temp_server_name]["log_file_name"]
-                        if "max_bytes" in config_data["honeypots"][temp_server_name]:
-                            max_bytes = config_data["honeypots"][temp_server_name]["max_bytes"]
-                        if "backup_count" in config_data["honeypots"][temp_server_name]:
-                            backup_count = config_data["honeypots"][temp_server_name]["backup_count"]
+                    if temp_server_name in config_data['honeypots']:
+                        if 'log_file_name' in config_data['honeypots'][temp_server_name]:
+                            temp_name = config_data['honeypots'][temp_server_name]['log_file_name']
+                        if 'max_bytes' in config_data['honeypots'][temp_server_name]:
+                            max_bytes = config_data['honeypots'][temp_server_name]['max_bytes']
+                        if 'backup_count' in config_data['honeypots'][temp_server_name]:
+                            backup_count = config_data['honeypots'][temp_server_name]['backup_count']
         except Exception as e:
             print(e)
-        if 'json' in logs:
-            formatter = json_file_formatter()
-        else:
-            formatter = Formatter('[%(asctime)s] [%(name)s] [%(levelname)s] - %(message)s')
-        file_handler = RotatingFileHandler(path.join(logs_location, temp_name), maxBytes=max_bytes, backupCount=backup_count)
-        file_handler.setFormatter(formatter)
+        file_handler = CustomHandlerFileRotate(temp_name, logs, custom_filter, path.join(logs_location, temp_name), maxBytes=max_bytes, backupCount=backup_count)
         ret_logs_obj.addHandler(file_handler)
     if 'syslog' in logs:
         if syslog_address == '':
@@ -264,11 +267,24 @@ def serialize_object(_dict):
         return repr(_dict).replace('\x00', ' ')
 
 
+class CustomHandlerFileRotate(RotatingFileHandler):
+    def __init__(self, uuid='', logs='', custom_filter=None, filename='', mode='a', maxBytes=0, backupCount=0, encoding=None, delay=False, errors=None):
+        self.logs = logs
+        self.custom_filter = custom_filter
+        RotatingFileHandler.__init__(self, filename, mode, maxBytes, backupCount, encoding, delay)
+
+    def emit(self, record):
+        _record = parse_record(record, self.custom_filter)
+        if _record is not None:
+            super().emit(_record)
+
+
 class CustomHandler(Handler):
-    def __init__(self, uuid='', logs='', config=None, drop=False):
+    def __init__(self, uuid='', logs='', custom_filter=None, config=None, drop=False):
         self.db = None
         self.logs = logs
         self.uuid = uuid
+        self.custom_filter = custom_filter
         if config and config != '':
             parsed = urlparse(config['postgres'])
             self.db = postgres_class(host=parsed.hostname, port=parsed.port, username=parsed.username, password=parsed.password, db=parsed.path[1:], uuid=self.uuid, drop=drop)
@@ -279,18 +295,24 @@ class CustomHandler(Handler):
             if 'db' in self.logs:
                 if self.db:
                     if isinstance(record.msg, list):
-                        if record.msg[0] == "sniffer" or record.msg[0] == "errors":
+                        if record.msg[0] == 'sniffer' or record.msg[0] == 'errors':
                             self.db.insert_into_data_safe(record.msg[0], dumps(serialize_object(record.msg[1]), cls=ComplexEncoder))
                     elif isinstance(record.msg, Mapping):
-                        if "server" in record.msg:
-                            self.db.insert_into_data_safe("servers", dumps(serialize_object(record.msg), cls=ComplexEncoder))
+                        if 'server' in record.msg:
+                            self.db.insert_into_data_safe('servers', dumps(serialize_object(record.msg), cls=ComplexEncoder))
             if 'terminal' in self.logs:
-                _record = parse_record(record)
-                stdout.write(dumps(_record.msg, sort_keys=True, cls=ComplexEncoder) + '\n')
+                _record = parse_record(record, self.custom_filter)
+                if _record:
+                    stdout.write(dumps(_record.msg, sort_keys=True, cls=ComplexEncoder) + '\n')
             if 'syslog' in self.logs:
-                _record = parse_record(record)
-                stdout.write(dumps(_record.msg, sort_keys=True, cls=ComplexEncoder) + '\n')
+                _record = parse_record(record, self.custom_filter)
+                if _record:
+                    stdout.write(dumps(_record.msg, sort_keys=True, cls=ComplexEncoder) + '\n')
         except Exception as e:
+            if self.custom_filter is not None:
+                if 'honeypots' in self.custom_filter:
+                    if 'remove_errors' in self.custom_filter['honeypots']['options']:
+                        return None
             stdout.write(dumps({'error': repr(e), 'logger': repr(record)}, sort_keys=True, cls=ComplexEncoder) + '\n')
         stdout.flush()
 
