@@ -56,7 +56,7 @@ class QSMTPServer():
                     return str(string)
 
             def smtp_EHLO(self, arg):
-                _q_s.logs.info({'server': 'smtp_server', 'action': 'connection', 'dest_ip': self.addr[0], 'dest_port': self.addr[1], 'src_ip': _q_s.ip, 'src_port': _q_s.port})
+                _q_s.logs.info({'server': 'smtp_server', 'action': 'connection', 'src_ip': self.addr[0], 'src_port': self.addr[1], 'dest_ip': _q_s.ip, 'dest_port': _q_s.port})
                 if not arg:
                     self.push('501 Syntax: HELO hostname')
                 if self._SMTPChannel__greeting:
@@ -79,7 +79,7 @@ class QSMTPServer():
                             username = _q_s.username
                             password = _q_s.password
                             status = 'success'
-                        _q_s.logs.info({'server': 'smtp_server', 'action': 'login', 'status': status, 'dest_ip': self.addr[0], 'dest_port': self.addr[1], 'src_ip': _q_s.ip, 'src_port': _q_s.port, 'username': username, 'password': password})
+                        _q_s.logs.info({'server': 'smtp_server', 'action': 'login', 'status': status, 'src_ip': self.addr[0], 'src_port': self.addr[1], 'dest_ip': _q_s.ip, 'dest_port': _q_s.port, 'username': username, 'password': password})
 
                 except Exception as e:
                     pass
@@ -120,7 +120,7 @@ class QSMTPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info({'server': 'smtp_server', 'action': 'process', 'status': status, 'dest_ip': self.ip, 'dest_port': self.port, 'username': self.username, 'password': self.password})
+            self.logs.info({'server': 'smtp_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password, 'dest_ip': self.ip, 'dest_port': self.port})
 
             if status == 'success':
                 return True
